@@ -79,7 +79,7 @@ class ProcessArgs( object ):
                           dest="output_format_str",
                           default = self.output_format,
                           choices = ["xml", "csv"],
-                          help="Choose an output format for a parser to read. Valid choice: xml")
+                          help="Choose an output format for a parser to read. Valid choices: xml, csv")
 
         # parse the command line/arguments for this instance
         try:
@@ -90,6 +90,10 @@ class ProcessArgs( object ):
             sys.stderr.writelines(parser.format_help())
             sys.exit( 1 )
 
+        print 'options: %s' % options
+        print 'args: %s' % args
+
+
         # augment parameter values from instantiation with
         #   command line values.
         # the command line parameter values take precidence
