@@ -6,11 +6,17 @@
 from metricbase import MetricBase
 
 token_types = [
-    b'Keyword',
-    b'Name',
-    b'Punctuation',
-    b'Operator',
-    b'Literal']
+    'Keyword',
+    'Name',
+    'Punctuation',
+    'Operator',
+    'Literal']
+# token_types = [
+#     b'Keyword',
+#     b'Name',
+#     b'Punctuation',
+#     b'Operator',
+#     b'Literal']
 
 
 class SLOCMetric(MetricBase):
